@@ -2,6 +2,7 @@ import click
 import configparser
 import json
 import getpass
+import os
 import re
 import requests
 import sys
@@ -104,6 +105,7 @@ def cli1():
 def web():
     """Simple program that label new issues on GitHub using webhooks."""
     print("Flask application created: SUCCESS")
+    print("In __main__: " + os.path.abspath(__file__))
     app.run()
 
 @click.group()
